@@ -1,5 +1,5 @@
 /*
- * Author: Petter Reinholdtsen <pere@td.org.uit.no>
+ * Author: Petter Reinholdtsen <pere@hungry.com>
  * date:   2001-01-20
  *
  * Alter ELF rpath information (insert, modify, remove).
@@ -79,9 +79,11 @@ main(int argc, char * const argv[])
     opt = GETOPT_LONG(argc, argv, "cdlr:v", long_options, &option_index);
     switch (opt)
       {
+#if defined(DT_RUNPATH)
       case 'c':
         convert = 1;
         break;
+#endif /* DT_RUNPATH */
       case 'd':
         remove = 1;
         break;
